package com.ruoyi.project.mapper;

import java.util.List;
import com.ruoyi.project.domain.TrsWordResults;

/**
 * WordresultsMapper接口
 * 
 * @author ruoyi
 * @date 2025-09-05
 */
public interface TrsWordResultsMapper 
{
    /**
     * 查询Wordresults
     * 
     * @param id Wordresults主键
     * @return Wordresults
     */
    public TrsWordResults selectTrsWordResultsById(Long id);

    /**
     * 查询Wordresults列表
     * 
     * @param trsWordResults Wordresults
     * @return Wordresults集合
     */
    public List<TrsWordResults> selectTrsWordResultsList(TrsWordResults trsWordResults);

    /**
     * 新增Wordresults
     * 
     * @param trsWordResults Wordresults
     * @return 结果
     */
    public int insertTrsWordResults(TrsWordResults trsWordResults);

    /**
     * 修改Wordresults
     * 
     * @param trsWordResults Wordresults
     * @return 结果
     */
    public int updateTrsWordResults(TrsWordResults trsWordResults);

    /**
     * 删除Wordresults
     * 
     * @param id Wordresults主键
     * @return 结果
     */
    public int deleteTrsWordResultsById(Long id);

    /**
     * 批量删除Wordresults
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTrsWordResultsByIds(String[] ids);
    public int deleteTrsWordResultsByLogIds(String[] ids);
}
